@@ -13,7 +13,7 @@ import glob
 import os.path
 import logging
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 __release__ = 20230204
 __all__ = ['read', 'concat']
 
@@ -47,7 +47,7 @@ def _read_one(path: str, raise_error=True, use_simpandas=None):
     elif path.split('.')[-1].lower() == 'lis':
         return lis2frame(path, use_simpandas=use_simpandas, raise_error=raise_error)
     elif not raise_error:
-        logging.warning("Not a valid log file: " + str(path))
+        # logging.warning("Not a valid log file: " + str(path))
         return None
     else:
         raise ValueError("`path` should be a '.las' or '.dlis' file")
