@@ -8,6 +8,7 @@ Created on Thu Jan 19 20:07:16 2023
 from dlisio import dlis
 import os.path
 import pandas as pd
+import numpy as np
 import logging
 from .log import Log
 from .pack import Pack
@@ -17,7 +18,7 @@ try:
 except ModuleNotFoundError:
     pass
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __release__ = 20230204
 
 
@@ -35,7 +36,13 @@ def dlis2frame(path: str, use_simpandas=False, raise_error=False):
         for p in range(len(logical_file.parameters)):
             meta.loc[p, 'name'] = logical_file.parameters[p].name
             meta.loc[p, 'long_name'] = logical_file.parameters[p].long_name
-            meta.loc[p, 'values'] = logical_file.parameters[p].values[0] if len(logical_file.parameters[p].values) > 0 else ''
+            if len(logical_file.parameters[p].values) > 0:
+                if isinstance(logical_file.parameters[p].values[0], np.ndarray):
+                    meta.loc[p, 'values'] = 'numpy.ndarray not loaded.'
+                else:
+                    meta.loc[p, 'values'] = logical_file.parameters[p].values[0]
+            else:
+                meta.loc[p, 'values'] = ''
             if logical_file.parameters[p].name == 'WN':
                 well_name = logical_file.parameters[p].values[0] if len(logical_file.parameters[p].values) else ''
         meta.set_index('name', inplace=True)
